@@ -55,6 +55,7 @@
 #include "semodule_core_process.h"
 #include "semanage_core_process.h"
 #include "semanage_core_login_process.h"
+#include "semanage_core_fcontext_process.h"
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
@@ -90,6 +91,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	semodule_core_process_o = 0;
 	semanage_core_process_o = 0;
 	semanage_core_login_process_o = 0;
+	semanage_core_fcontext_process_o = 0;
 
 	//connect SIGNAL to objects    
 
@@ -105,7 +107,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex-4.30"));
+	setCaption(tr("segatex-4.40"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -414,6 +416,11 @@ void MainWindow::createActions()
 	semanage_core_login_processAct->setStatusTip(tr("Semanage login -a -m -d."));
 	connect(semanage_core_login_processAct, SIGNAL(activated()), this, SLOT(semanage_core_login_process()));
 	connect(semanage_core_login_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	semanage_core_fcontext_processAct = new QAction(tr("&semanage fcontext"), 0, this);
+	semanage_core_fcontext_processAct->setStatusTip(tr("Semanage fcontext -a -m -d."));
+	connect(semanage_core_fcontext_processAct, SIGNAL(activated()), this, SLOT(semanage_core_fcontext_process()));
+	connect(semanage_core_fcontext_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 void MainWindow::createMenus()
@@ -490,6 +497,7 @@ void MainWindow::createMenus()
 	semanageMenu = new QPopupMenu(this);
 	semanage_core_processAct->addTo(semanageMenu);
 	semanage_core_login_processAct->addTo(semanageMenu);
+	semanage_core_fcontext_processAct->addTo(semanageMenu);
 
 	menuBar()->insertItem(tr("&File"), fileMenu);
 	menuBar()->insertItem(tr("&Edit"), editMenu);
@@ -841,7 +849,7 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-4.30</h2>"
+		tr("<h2>segatex-4.40</h2>"
 		"<p>Copyright &copy; 2007"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex_suite is a SELinux tool"
@@ -1038,3 +1046,12 @@ void MainWindow::semanage_core_login_process()
 	semanage_core_login_process_o->raise();
 	semanage_core_login_process_o->setActiveWindow();
 }
+void MainWindow::semanage_core_fcontext_process()
+{
+	if(!semanage_core_fcontext_process_o) {
+		semanage_core_fcontext_process_o = new SemanageCoreFcontextProcess(this);
+	}
+	semanage_core_fcontext_process_o->show();
+	semanage_core_fcontext_process_o->raise();
+	semanage_core_fcontext_process_o->setActiveWindow();
+}
