@@ -52,6 +52,7 @@ class SegatexCore;
 class SemoduleCoreProcess;
 class SemanageCoreProcess;
 class SemanageCoreLoginProcess;
+class SemanageCoreFcontextProcess;
 
 class MainWindow : public QMainWindow
 {
@@ -102,6 +103,7 @@ private slots:
     void semodule_core_process();
     void semanage_core_process();
     void semanage_core_login_process();
+    void semanage_core_fcontext_process();
 
     void save();
     void saveAs();
@@ -166,6 +168,7 @@ private:
     SemoduleCoreProcess *semodule_core_process_o;
     SemanageCoreProcess *semanage_core_process_o;
     SemanageCoreLoginProcess *semanage_core_login_process_o;
+    SemanageCoreFcontextProcess *semanage_core_fcontext_process_o;
     
     QPopupMenu *fileMenu;
     QPopupMenu *editMenu;
@@ -232,6 +235,7 @@ private:
     QAction *semodule_core_processAct;
     QAction *semanage_core_processAct;
     QAction *semanage_core_login_processAct;
+    QAction *semanage_core_fcontext_processAct;
 };
 
 #endif
