@@ -282,6 +282,7 @@ void ParseLinesMisc::analize_file_patterns()
 // it should have space otherwise getattr_dir_perms and r_dir_perms would collide
 // When refpolicy updated...
 // please copy lines what outputed data i.e. obj_perm_sets_analized_ready,txt by both obj perm sets button and misc patterns buttons.
+//
 lines_break.gres(" dir_file_class_set","{ dir file lnk_file sock_file fifo_file chr_file blk_file }");
 lines_break.gres(" file_class_set","{ file lnk_file sock_file fifo_file chr_file blk_file }");
 lines_break.gres(" notdevfile_class_set","{ file lnk_file sock_file fifo_file }");
@@ -561,11 +562,9 @@ lines_break.gres(" rx_file_perms","{ read getattr lock execute ioctl }");
 lines_break.gres(" ra_file_perms","{ ioctl read getattr lock append }");
 lines_break.gres(" link_file_perms","{ getattr link unlink rename }");
 lines_break.gres(" create_lnk_perms","{ create read getattr setattr link unlink rename }");
-lines_break.gres(" create_file_perms","{ create ioctl read getattr lock write setattr append link unlink rename }");
 lines_break.gres(" r_dir_perms","{ read getattr lock search ioctl }");
 lines_break.gres(" rw_dir_perms","{ read getattr lock search ioctl add_name remove_name write }");
-lines_break.gres(" ra_dir_perms","{ read getattr lock search ioctl add_name write }");
-lines_break.gres(" create_dir_perms","{ create read getattr lock setattr ioctl link unlink rename search add_name remove_name reparent write rmdir }");
+lines_break.gres(" ra_dir_perms","{ read getattr lock search ioctl add_name write } ");
 lines_break.gres(" mount_fs_perms","{ mount remount unmount getattr }");
 lines_break.gres(" rw_socket_perms","{ ioctl read getattr write setattr append bind connect getopt setopt shutdown }");
 lines_break.gres(" create_socket_perms","{ create rw_socket_perms }");
@@ -786,11 +785,9 @@ lines_break.gres(" rx_file_perms","{ read getattr lock execute ioctl }");
 lines_break.gres(" ra_file_perms","{ ioctl read getattr lock append }");
 lines_break.gres(" link_file_perms","{ getattr link unlink rename }");
 lines_break.gres(" create_lnk_perms","{ create read getattr setattr link unlink rename }");
-lines_break.gres(" create_file_perms","{ create ioctl read getattr lock write setattr append link unlink rename }");
 lines_break.gres(" r_dir_perms","{ read getattr lock search ioctl }");
 lines_break.gres(" rw_dir_perms","{ read getattr lock search ioctl add_name remove_name write }");
-lines_break.gres(" ra_dir_perms","{ read getattr lock search ioctl add_name write }");
-lines_break.gres(" create_dir_perms","{ create read getattr lock setattr ioctl link unlink rename search add_name remove_name reparent write rmdir }");
+lines_break.gres(" ra_dir_perms","{ read getattr lock search ioctl add_name write } ");
 lines_break.gres(" mount_fs_perms","{ mount remount unmount getattr }");
 lines_break.gres(" rw_socket_perms","{ ioctl read getattr write setattr append bind connect getopt setopt shutdown }");
 lines_break.gres(" create_socket_perms","{ create rw_socket_perms }");
